OwnedComputeInstance

Struct OwnedComputeInstance 

pub struct OwnedComputeInstance(/* private fields */);

Implementations

Methods from Deref<Target = ComputeInstance>

pub fn as_raw(&self) -> nvmlComputeInstance_t

pub fn is_null(&self) -> bool

pub fn info(&self) -> Result<ComputeInstanceInfo>

Returns compute instance information.

For Ampere or newer fully supported devices. Supported on Linux only.

Errors

Returns an error if the handle or output arguments are rejected by NVML, if the current process does not have permission to query the instance, or if NVML has not been initialized.

pub fn parent_device(&self) -> Result<Device>

pub fn parent_gpu_instance(&self) -> Result<GpuInstance>

pub fn id(&self) -> Result<u32>

pub fn profile_id(&self) -> Result<u32>

pub fn placement(&self) -> Result<ComputeInstancePlacement>